ConnectionSet

Type Alias ConnectionSet 

pub type ConnectionSet = ConnectionSystems;
👎Deprecated:

Use ConnectionSystems instead

Aliased Type

pub enum ConnectionSet {
    Receive,
    Send,
}

Variants



Receive

Receive bytes from the Link, process them as Packets and buffer them into the Transport



Send

Flush the messages that were buffered into the Transport, process them as Packets and buffer them to the Link